sc/source/core/tool/compiler.cxx |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit a7c9101b1a932c0d481dd3d39108a26548895be6
Author:     Eike Rathke <er...@redhat.com>
AuthorDate: Fri Jun 24 00:06:13 2022 +0200
Commit:     Eike Rathke <er...@redhat.com>
CommitDate: Fri Jun 24 02:26:30 2022 +0200

    Avoid i18n uppercase overhead also for OOXML
    
    Change-Id: I0f5bdbac95bd764ce6d15f87d41717334b401ef1
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/136354
    Reviewed-by: Eike Rathke <er...@redhat.com>
    Tested-by: Jenkins

diff --git a/sc/source/core/tool/compiler.cxx b/sc/source/core/tool/compiler.cxx
index 2945062f1b37..1f83d27d3c3f 100644
--- a/sc/source/core/tool/compiler.cxx
+++ b/sc/source/core/tool/compiler.cxx
@@ -4314,10 +4314,10 @@ void ScCompiler::AutoCorrectParsedSymbol()
 
 bool ScCompiler::ToUpperAsciiOrI18nIsAscii( OUString& rUpper, const OUString& 
rOrg ) const
 {
-    if (FormulaGrammar::isODFF( meGrammar ))
+    if (FormulaGrammar::isODFF( meGrammar) || FormulaGrammar::isOOXML( 
meGrammar))
     {
         // ODFF has a defined set of English function names, avoid i18n
         // overhead.
         rUpper = rOrg.toAsciiUpperCase();
         return true;
     }
@@ -4314,10 +4314,10 @@ void ScCompiler::AutoCorrectParsedSymbol()
meGrammar))
     {
-        // ODFF has a defined set of English function names, avoid i18n
-        // overhead.
+        // ODFF and OOXML have defined sets of English function names, avoid
+        // i18n overhead.
         rUpper = rOrg.toAsciiUpperCase();
         return true;

Reply via email to